@@ -3,7 +3,7 @@
 *                           O p e n G L   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2016 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2017 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -119,16 +119,16 @@ public:
   virtual FXbool drag(FXGLViewer* viewer,FXint fx,FXint fy,FXint tx,FXint ty);
 
   /// Return number of children
-  FXint no() const { return list.no(); }
+  FXival no() const { return list.no(); }
 
   /// Child at position
-  FXGLObject* child(FXint pos) const { return list[pos]; }
+  FXGLObject* child(FXival pos) const { return list[pos]; }
 
   /// Insert child object at given position
-  void insert(FXint pos,FXGLObject* obj){ list.insert(pos,obj); }
+  void insert(FXival pos,FXGLObject* obj){ list.insert(pos,obj); }
 
   /// Insert list of child objects at given position
-  void insert(FXint pos,const FXGLObjectList& objs){ list.insert(pos,objs); }
+  void insert(FXival pos,const FXGLObjectList& objs){ list.insert(pos,objs); }
 
   /// Prepend child object
   void prepend(FXGLObject* obj){ list.prepend(obj); }
@@ -143,13 +143,13 @@ public:
   void append(const FXGLObjectList& objs){ list.append(objs); }
 
   /// Replace child object
-  void replace(FXint pos,FXGLObject* obj){ list.replace(pos,obj); }
+  void replace(FXival pos,FXGLObject* obj){ list.replace(pos,obj); }
 
   /// Remove child object
   void remove(FXGLObject* obj){ list.remove(obj); }
 
   /// Remove child object at given position
-  void erase(FXint pos){ list.erase(pos); }
+  void erase(FXival pos){ list.erase(pos); }
 
   /// Remove all children
   void clear(){ list.clear(); }
@@ -163,77 +163,6 @@ public:
   };
 
 
-/// OpenGL Point Object
-class FXAPI FXGLPoint : public FXGLObject {
-  FXDECLARE(FXGLPoint)
-public:
-  FXVec3f pos;
-public:
-
-  /// Default constructor
-  FXGLPoint();
-
-  /// Copy constructor
-  FXGLPoint(const FXGLPoint& orig);
-
-  /// Construct with specified coordinates
-  FXGLPoint(FXfloat x,FXfloat y,FXfloat z);
-
-  /// Copy this object
-  virtual FXGLObject* copy();
-
-  /// Called by the viewer to get bounds for this object
-  virtual void bounds(FXRangef& box);
-
-  /// Draw this object in a viewer
-  virtual void draw(FXGLViewer* viewer);
-
-  /// Draw this object for hit-testing purposes
-  virtual void hit(FXGLViewer* viewer);
-
-  /// Save to a stream
-  virtual void save(FXStream& store) const;
-
-  /// Load from a stream
-  virtual void load(FXStream& store);
-  };
-
-
-/// OpenGL Line Object
-class FXAPI FXGLLine : public FXGLObject {
-  FXDECLARE(FXGLLine)
-public:
-  FXGLPoint fm,to;
-public:
-
-  /// Default constructor
-  FXGLLine();
-
-  /// Copy constructor
-  FXGLLine(const FXGLLine& orig);
-
-  /// Construct with specified endpoints
-  FXGLLine(FXfloat fx,FXfloat fy,FXfloat fz,FXfloat tx,FXfloat ty,FXfloat tz);
-
-  /// Called by the viewer to get bounds for this object
-  virtual void bounds(FXRangef& box);
-
-  /// Draw this object in a viewer
-  virtual void draw(FXGLViewer* viewer);
-
-  /// Copy this object
-  virtual FXGLObject* copy();
-
-  /// Draw this object for hit-testing purposes
-  virtual void hit(FXGLViewer* viewer);
-
-  /// Save to a stream
-  virtual void save(FXStream& store) const;
-
-  /// Load from a stream
-  virtual void load(FXStream& store);
-  };
-
 }
 
 #endif
